@@ -86,6 +86,8 @@ TopologyFunc = function(spgeom, id, byid, func) {
         x <- .Call("rgeos_pointonsurface", .RGEOS_HANDLE, spgeom, id, byid, PACKAGE="rgeos")
     else if (func == "rgeos_unioncascaded")
         x <- .Call("rgeos_unioncascaded", .RGEOS_HANDLE, spgeom, id, byid, PACKAGE="rgeos")
+    else if (func == "rgeos_makevalid")
+        x <- .Call("rgeos_makevalid", .RGEOS_HANDLE, spgeom, id, byid, PACKAGE="rgeos")
     else stop("no such function:", func)
 
 
@@ -152,6 +154,14 @@ gUnionCascaded = function(spgeom, id = NULL) {
     res
 }
 
+gMakeValid = function(spgeom, byid=FALSE, id = NULL) {
+
+    if (version_GEOS0() < "3.8.0")
+        stop("No UnaryUnion in this version of GEOS")
+    return( TopologyFunc(spgeom, id, byid, "rgeos_makevalid") ) 
+
+}
+
 gUnaryUnion = function(spgeom, id = NULL, checkValidity=NULL) {
 
     if (version_GEOS0() < "3.3.0")
